@@ -60,10 +60,14 @@ compdef _cli_zsh_autocomplete helmwave
 )
 
 var (
+	// ErrWrongShell is an error for unsupported shell.
 	ErrWrongShell = errors.New("wrong shell")
-	ErrNotChose   = errors.New("you did not specify a shell")
+
+	// ErrNotChose is an error for not provided shell name.
+	ErrNotChose = errors.New("you did not specify a shell")
 )
 
+//nolint:forbidigo // we need to use fmt.Print
 func completion() *cli.Command {
 	return &cli.Command{
 		Name:  "completion",
@@ -73,16 +77,18 @@ func completion() *cli.Command {
 			 echo "source <(helmwave completion zsh)" >> ~/.zshrc"
 		`,
 		Action: func(c *cli.Context) error {
-			if 0 == c.Args().Len() {
+			if c.Args().Len() == 0 {
 				return ErrNotChose
 			}
 
 			switch c.Args().First() {
 			case "bash":
-				fmt.Print(bash) // nolint:forbidigo
+				fmt.Print(bash)
+
 				return nil
 			case "zsh":
-				fmt.Print(zsh) // nolint:forbidigo
+				fmt.Print(zsh)
+
 				return nil
 			default:
 				return ErrWrongShell
