@@ -1,17 +1,22 @@
 package action
 
 import (
+	"context"
+
 	"github.com/helmwave/helmwave/pkg/template"
 	log "github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
 )
 
+// Yml is struct for running 'yml' command.
 type Yml struct {
 	tpl, file string
+	templater string
 }
 
-func (i *Yml) Run() error {
-	err := template.Tpl2yml(i.tpl, i.file, nil)
+// Run is main function for 'yml' command.
+func (i *Yml) Run(ctx context.Context) error {
+	err := template.Tpl2yml(i.tpl, i.file, nil, i.templater)
 	if err != nil {
 		return err
 	}
@@ -24,6 +29,7 @@ func (i *Yml) Run() error {
 	return nil
 }
 
+// Cmd returns 'yml' *cli.Command.
 func (i *Yml) Cmd() *cli.Command {
 	return &cli.Command{
 		Name:   "yml",
@@ -37,5 +43,6 @@ func (i *Yml) flags() []cli.Flag {
 	return []cli.Flag{
 		flagTplFile(&i.tpl),
 		flagYmlFile(&i.file),
+		flagTemplateEngine(&i.templater),
 	}
 }
