@@ -10,32 +10,37 @@ import (
 	log "github.com/sirupsen/logrus"
 )
 
-func buildGraphMD(releases []*release.Config) string {
-	md :=
-		"# Depends On\n\n" +
-			"```mermaid\ngraph RL\n"
+func buildGraphMD(releases release.Configs) string {
+	md := "# Depends On\n\n" +
+		"```mermaid\ngraph RL\n"
 
 	for _, r := range releases {
-		for _, dep := range r.DependsOn {
+		for _, dep := range r.DependsOn() {
 			md += fmt.Sprintf(
 				"\t%s[%q] --> %s[%q]\n",
-				strings.Replace(string(r.Uniq()), "@", "_", -1), r.Uniq(), // nolint:gocritic
-				strings.Replace(dep, "@", "_", -1), dep, // nolint:gocritic
+				strings.ReplaceAll(r.Uniq().String(), "@", "_"), r.Uniq(),
+				strings.ReplaceAll(dep.Uniq().String(), "@", "_"), dep.Uniq().String(),
 			)
 		}
 	}
 
 	md += "```"
+
 	return md
 }
 
-func buildGraphASCII(releases []*release.Config) string {
+func buildGraphASCII(releases release.Configs) string {
 	list := make([]core.NodeInput, 0, len(releases))
 
 	for _, rel := range releases {
+		deps := make([]string, len(rel.DependsOn()))
+		for i, d := range rel.DependsOn() {
+			deps[i] = d.Uniq().String()
+		}
+
 		l := core.NodeInput{
-			Id:   string(rel.Uniq()),
-			Next: rel.DependsOn,
+			Id:   rel.Uniq().String(),
+			Next: deps,
 		}
 
 		list = append(list, l)
