@@ -9,11 +9,17 @@ import (
 	"helm.sh/helm/v3/pkg/release"
 )
 
+//nolint:gochecknoglobals // cannot make these colors const
 var (
-	FailStatusColor    = tablewriter.Color(tablewriter.Bold, tablewriter.BgRedColor)
+	// FailStatusColor is tablewriter color for failed releases.
+	FailStatusColor = tablewriter.Color(tablewriter.Bold, tablewriter.BgRedColor)
+
+	// SuccessStatusColor is tablewriter color for succeeded releases.
 	SuccessStatusColor = tablewriter.Color(tablewriter.Bold, tablewriter.BgRedColor)
 )
 
+// List renders releases status table and writes it to stdout.
+// Listed only releases that exist in plan.
 func (p *Plan) List() error {
 	log.Infof("Should be %d releases", len(p.body.Releases))
 	if len(p.body.Releases) == 0 {
@@ -25,7 +31,8 @@ func (p *Plan) List() error {
 	for _, rel := range p.body.Releases {
 		r, err := rel.List()
 		if err != nil {
-			log.Errorf("Failed to list %s release, skipping: %v", string(rel.Uniq()), err)
+			rel.Logger().WithError(err).Error("Failed to list. Skipping.")
+
 			continue
 		}
 
