@@ -3,22 +3,22 @@ package plan
 import (
 	"github.com/helmwave/helmwave/pkg/parallel"
 	"github.com/helmwave/helmwave/pkg/release"
-	log "github.com/sirupsen/logrus"
 )
 
-func (p *Plan) Rollback() error {
+// Rollback rollbacks helm release.
+func (p *Plan) Rollback(version int) error {
 	wg := parallel.NewWaitGroup()
 	wg.Add(len(p.body.Releases))
 
 	for i := range p.body.Releases {
-		go func(wg *parallel.WaitGroup, rel *release.Config) {
+		go func(wg *parallel.WaitGroup, rel release.Config) {
 			defer wg.Done()
-			err := rel.Rollback()
+			err := rel.Rollback(version)
 			if err != nil {
-				log.Errorf("❌ %s: %v", rel.Uniq(), err)
+				rel.Logger().WithError(err).Error("❌ rollback")
 				wg.ErrChan() <- err
 			} else {
-				log.Infof("✅ %s rollback!", rel.Uniq())
+				rel.Logger().Info("✅ rollback!")
 			}
 		}(wg, p.body.Releases[i])
 	}
