@@ -2,6 +2,8 @@ package release
 
 import (
 	"strings"
+
+	"helm.sh/helm/v3/pkg/registry"
 )
 
 // // RepoDeps returns repository for release
@@ -26,6 +28,11 @@ import (
 //	return repos, nil
 // }
 
-func (rel *Config) Repo() string {
-	return strings.Split(rel.Chart.Name, "/")[0]
+func (rel *config) Repo() string {
+	s := rel.Chart().Name
+	if registry.IsOCI(s) {
+		s = strings.TrimPrefix(s, registry.OCIScheme+"://")
+	}
+
+	return strings.Split(s, "/")[0]
 }
